==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/mediaplayer/translations/mediaplayer_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Syntax: %t - song title,
%a - album, %r - artist, %f - file name,
%l - song length (MM:SS), %c - current song position (MM:SS),
%p - percents of played song, %n - player name, %v - player version
</source>
        <translation>Syntaxe : %t - titre de la chanson,
%a - album, %r - artiste, %f - nom du fichier,
%l - durée de la chanson (MM:SS), %c - position de lecture actuelle de la chanson (MM:SS),
%p - pourcentage de lecture de la chanson, %n - nom du lecteur, %v - version du lecteur
</translation>
    </message>
    <message>
        <source>Pseudo-OSD for MediaPlayer</source>
        <translation>Pseudo-OSD pour MediaPlayer</translation>
    </message>
    <message>
        <source>MediaPlayer</source>
        <translation>MediaPlayer</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <source>MediaPlayer message format for chat windows</source>
        <translation>Format de message MediaPlayer pour la fenêtre de conversation</translation>
    </message>
    <message>
        <source>MediaPlayer statuses in description</source>
        <translation>États de MediaPlayer dans description</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Remplacer</translation>
    </message>
    <message>
        <source>MediaPlayer description format</source>
        <translation>Remplacer</translation>
    </message>
    <message>
        <source>Here specify format which will replace &apos;#{player}&apos; tag when you will use it in description while setting status.</source>
        <translation>Indiquez ici le format qui remplacera le mot clef &apos;#{player}&apos; quand vous l&apos;utiliserez dans la description lors du réglage de l&apos;état.</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Activer</translation>
    </message>
    <message>
        <source>Signatures to cut</source>
        <translation>Signatures à couper</translation>
    </message>
    <message>
        <source>Crap to cut</source>
        <translation>Partie inutile à couper</translation>
    </message>
    <message>
        <source>Enable pseudo-OSD</source>
        <translation>Activer pseudo-OSD</translation>
    </message>
    <message>
        <source>Enables pseudo-OSD done by Kadu hints. Shows currently played title in hint.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable MediaPlayer keyboard shortcuts in chat window</source>
        <translation>Activer les raccourcis clavier de MediaPlayer dans la fenêtre de conversation</translation>
    </message>
    <message>
        <source>Put statuses switch to dock menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable this to put MediaPlayer statuses switch into docked icon menu.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Paramètres généraux</translation>
    </message>
    <message>
        <source>Signature Cutting</source>
        <translation>Coupure de la signature</translation>
    </message>
    <message>
        <source>Shall I cut this crap?</source>
        <translation>Dois-je couper cette partie inutile ?</translation>
    </message>
    <message>
        <source>Other Settings</source>
        <translation>Autres paramètres</translation>
    </message>
    <message>
        <source>With this option enabled you'll be able to control
your MediaPlayer in chat window by keyboard shortcuts:
Control+ Enter/Backspace/Left/Right/Up/Down.</source>
        <translation>Avec cette option activée vous serez capable de contrôler 
MediaPlayer dans la fenêtre de conversation grâce aux raccourcis clavier :
Ctrl+Entrée/Espace/Gauche/Droite/Haut/Bas.</translation>
    </message>
    <message>
        <source>With this option enabled you'll be able to control
your MediaPlayer in chat window by keyboard shortcuts:
Win+ Enter/Backspace/Left/Right/Up/Down.</source>
        <translation>Avec cette option activée vous serez capable de contrôler 
MediaPlayer dans la fenêtre de conversation grâce aux raccourcis clavier :
Meta+Entrée/Espace/Gauche/Droite/Haut/Bas.</translation>
    </message>
    <message>
        <source>Add in the Front</source>
        <translation>Ajouter devant</translation>
    </message>
    <message>
        <source>Add at the Back</source>
        <translation>Ajouter derrière</translation>
    </message>
    <message>
        <source>Replace &apos;#{player}&apos; Tag</source>
        <translation>Remplacer &apos;#{player}&apos; mot-clef</translation>
    </message>
</context>
<context>
    <name>MediaPlayer</name>
    <message>
        <source>Put formated string</source>
        <translation>Donner la chaîne formatée</translation>
    </message>
    <message>
        <source>Put song title</source>
        <translation>Donner le titre de la chanson</translation>
    </message>
    <message>
        <source>Put song file name</source>
        <translation>Donner le nom de fichier de la chanson</translation>
    </message>
    <message>
        <source>Send all playlist titles</source>
        <translation>Envoyer tous les titres de la playlist</translation>
    </message>
    <message>
        <source>Send all playlist files</source>
        <translation>Envoyer tous les fichiers de la playlist</translation>
    </message>
    <message>
        <source>Enable MediaPlayer statuses</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>MediaPlayer</source>
        <translation>MediaPlayer</translation>
    </message>
    <message>
        <source>%1 isn&apos;t running!</source>
        <translation>%1 n&apos;est pas en cours de lecture !</translation>
    </message>
    <message>
        <source>You&apos;re trying to send %1 entries of %2 playlist.&lt;br&gt;It will be split and sent in few messages&lt;br&gt;Are you sure to do that?</source>
        <translation>Vous essayez d&apos;envoyer %1 éléments de la playlist %2.&lt;br&gt;Il sera divisé et envoyé en quelques messages&lt;br&gt;Êtes-vous certain de vouloir faire ça ?</translation>
    </message>
    <message>
        <source>Playback stopped.</source>
        <translation>Playback arrêté.</translation>
    </message>
    <message>
        <source>Player turned off.</source>
        <translation>Lecteur éteint.</translation>
    </message>
    <message>
        <source>Enable MediaPlayer Statuses</source>
        <translation>Activer des états MediaPlayer</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Lire</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <source>Previous Track</source>
        <translation>Piste précédente</translation>
    </message>
    <message>
        <source>Next Track</source>
        <translation>Piste suivante</translation>
    </message>
    <message>
        <source>Volume Up</source>
        <translation>Augmenter le volume</translation>
    </message>
    <message>
        <source>Volume Down</source>
        <translation>Baisser le volume</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>More than 1/10 of titles you&apos;re trying to send are empty.&lt;br&gt;Perhaps %1 hasn&apos;t read all titles yet, give its some more time.&lt;br&gt;Do you want to send playlist anyway?</source>
        <translation>Plus d&apos;un dixième des titres que vous tentez d&apos;envoyer sont vides.&lt;br&gt;Peut-être que %1 n&apos;a pas encore lu tous les titres ; donnez lui plus de temps.&lt;br&gt;Voulez-vous tout de même envoyer la playlist ?</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Player isn&apos;t running!</source>
        <translation>Le lecteur n&apos;est pas en cours de lecture !</translation>
    </message>
</context>
</TS>

==> kadu_1.3.orig.tar.bz2: kadu-1.3/plugins/mediaplayer/translations/mediaplayer_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Syntax: %t - song title,
%a - album, %r - artist, %f - file name,
%l - song length (MM:SS), %c - current song position (MM:SS),
%p - percents of played song, %n - player name, %v - player version
</source>
        <translation>Syntaxe : %t - titre de la chanson,
%a - album, %r - artiste, %f - nom du fichier,
%l - durée de la chanson (MM:SS), %c - position de lecture actuelle de la chanson (MM:SS),
%p - pourcentage de lecture de la chanson, %n - nom du lecteur, %v - version du lecteur
</translation>
    </message>
    <message>
        <source>Pseudo-OSD for MediaPlayer</source>
        <translation>Pseudo-OSD pour MediaPlayer</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <source>MediaPlayer statuses in description</source>
        <translation>États de MediaPlayer dans description</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Remplacer</translation>
    </message>
    <message>
        <source>MediaPlayer description format</source>
        <translation>Remplacer</translation>
    </message>
    <message>
        <source>Here specify format which will replace &apos;#{player}&apos; tag when you will use it in description while setting status.</source>
        <translation>Indiquez ici le format qui remplacera le mot clef &apos;#{player}&apos; quand vous l&apos;utiliserez dans la description lors du réglage de l&apos;état.</translation>
    </message>
    <message>
        <source>Signatures to cut</source>
        <translation>Signatures à couper</translation>
    </message>
    <message>
        <source>Crap to cut</source>
        <translation>Partie inutile à couper</translation>
    </message>
    <message>
        <source>Enable pseudo-OSD</source>
        <translation>Activer pseudo-OSD</translation>
    </message>
    <message>
        <source>Enables pseudo-OSD done by Kadu hints. Shows currently played title in hint.</source>
        <translation>Enables pseudo-OSD done by Kadu hints. Shows currently played title in hint.</translation>
    </message>
    <message>
        <source>Enable MediaPlayer keyboard shortcuts in chat window</source>
        <translation>Activer les raccourcis clavier de MediaPlayer dans la fenêtre de conversation</translation>
    </message>
    <message>
        <source>Put statuses switch to dock menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable this to put MediaPlayer statuses switch into docked icon menu.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Signature Cutting</source>
        <translation>Coupure de la signature</translation>
    </message>
    <message>
        <source>Other Settings</source>
        <translation>Autres paramètres</translation>
    </message>
    <message>
        <source>With this option enabled you'll be able to control
your MediaPlayer in chat window by keyboard shortcuts:
Control+ Enter/Backspace/Left/Right/Up/Down.</source>
        <translation>Avec cette option activée vous serez capable de contrôler 
MediaPlayer dans la fenêtre de conversation grâce aux raccourcis clavier :
Ctrl+Entrée/Espace/Gauche/Droite/Haut/Bas.</translation>
    </message>
    <message>
        <source>With this option enabled you'll be able to control
your MediaPlayer in chat window by keyboard shortcuts:
Win+ Enter/Backspace/Left/Right/Up/Down.</source>
        <translation>Avec cette option activée vous serez capable de contrôler 
MediaPlayer dans la fenêtre de conversation grâce aux raccourcis clavier :
Meta+Entrée/Espace/Gauche/Droite/Haut/Bas.</translation>
    </message>
    <message>
        <source>Add in the Front</source>
        <translation>Ajouter devant</translation>
    </message>
    <message>
        <source>Add at the Back</source>
        <translation>Ajouter derrière</translation>
    </message>
    <message>
        <source>Replace &apos;#{player}&apos; Tag</source>
        <translation>Remplacer &apos;#{player}&apos; mot-clef</translation>
    </message>
    <message>
        <source>Extras</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Media Player</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>MediaPlayer message format in chat window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable signature cutting</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable removing non-essential stuff from audio file titles</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaPlayer</name>
    <message>
        <source>Put formated string</source>
        <translation>Donner la chaîne formatée</translation>
    </message>
    <message>
        <source>Put song title</source>
        <translation>Donner le titre de la chanson</translation>
    </message>
    <message>
        <source>Put song file name</source>
        <translation>Donner le nom de fichier de la chanson</translation>
    </message>
    <message>
        <source>Send all playlist titles</source>
        <translation>Envoyer tous les titres de la playlist</translation>
    </message>
    <message>
        <source>Send all playlist files</source>
        <translation>Envoyer tous les fichiers de la playlist</translation>
    </message>
    <message>
        <source>Enable MediaPlayer statuses</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>MediaPlayer</source>
        <translation>MediaPlayer</translation>
    </message>
    <message>
        <source>%1 isn&apos;t running!</source>
        <translation>%1 n&apos;est pas en cours de lecture !</translation>
    </message>
    <message>
        <source>You&apos;re trying to send %1 entries of %2 playlist.&lt;br&gt;It will be split and sent in few messages&lt;br&gt;Are you sure to do that?</source>
        <translation>Vous essayez d&apos;envoyer %1 éléments de la playlist %2.&lt;br&gt;Il sera divisé et envoyé en quelques messages&lt;br&gt;Êtes-vous certain de vouloir faire ça ?</translation>
    </message>
    <message>
        <source>Playback stopped.</source>
        <translation>Playback arrêté.</translation>
    </message>
    <message>
        <source>Player turned off.</source>
        <translation>Lecteur éteint.</translation>
    </message>
    <message>
        <source>Enable MediaPlayer Statuses</source>
        <translation>Activer des états MediaPlayer</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Lire</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <source>Previous Track</source>
        <translation>Piste précédente</translation>
    </message>
    <message>
        <source>Next Track</source>
        <translation>Piste suivante</translation>
    </message>
    <message>
        <source>Volume Up</source>
        <translation>Augmenter le volume</translation>
    </message>
    <message>
        <source>Volume Down</source>
        <translation>Baisser le volume</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>More than 1/10 of titles you&apos;re trying to send are empty.&lt;br&gt;Perhaps %1 hasn&apos;t read all titles yet, give its some more time.&lt;br&gt;Do you want to send playlist anyway?</source>
        <translation>Plus d&apos;un dixième des titres que vous tentez d&apos;envoyer sont vides.&lt;br&gt;Peut-être que %1 n&apos;a pas encore lu tous les titres ; donnez lui plus de temps.&lt;br&gt;Voulez-vous tout de même envoyer la playlist ?</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Player isn&apos;t running!</source>
        <translation>Le lecteur n&apos;est pas en cours de lecture !</translation>
    </message>
    <message>
        <source>Send anyway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Send</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
